solr2es
-------

.. image:: https://circleci.com/gh/ICIJ/solr2es.png?style=shield&circle-token=846c844f540fb3746b80b8f12656ddde665b5037
   :alt: Circle CI
   :target: https://circleci.com/gh/ICIJ/solr2es

Migration script from solr to elasticsearch